## The very first Contribution
Thank you for wanting to contribute to waloviz!  
There is one way in which you can contribute that takes only one second:  
:star2: **Please consider giving waloviz a github star** :star2:  

Even if you do not give a star, you are the best!  
Using waloviz, telling a friend about it or making contributions are all amazing ways in which waloviz can become more useful for more people.  
For that I am greatful :heart:

## Can I Contribute more?
**YES!**  
waloviz is early on its path, and there are lots of ways in which it can become better.  
Here is a not comprehensive list of possible Contributions: 
* **Read the Roadmap** - find it in the [readme](README.md), you might be able to help in ways that we didn't even realize!
* **Improve the Documentation** - It is the highest priority
* **Write Tests** - Second only to Documentation
* **Automate processes** - Anything from bots to github actions, your knowledge can help waloviz save precious time
* **Create an Issue** - before jumping straight into creating PRs, create an Issue that explains your reasoning\problem to the community  
* **Comment\Upvote an Issue** - We'd love to hear your opinion on open Issues! We will listen
* **Solve an Issue with a PR** - after you actively engaged with the Issue in the comments and were given the PR responsibility
* **Talk with the community** - your engagement **is** the community, as long as it adheres to the [code of conduct](CODE_OF_CONDUCT.md)
